@@ -5,7 +5,6 @@ module.exports = {
       label: "💡 Getting Started",
       collapsed: false,
       items: [
-        "introduction",
         {
           type: "category",
           label: "🚀 Get started",
@@ -24,6 +23,7 @@ module.exports = {
             "installation/fonts",
             "installation/prompt",
             "installation/customize",
+            "installation/upgrade",
           ],
         },
       ],
@@ -31,6 +31,10 @@ module.exports = {
     {
       type: "category",
       label: "⚙️ Configuration",
+      link: {
+        type: 'doc',
+        id: 'configuration/introduction',
+      },
       items: [
         "configuration/general",
         "configuration/block",
@@ -58,6 +62,7 @@ module.exports = {
           items: [
             "segments/cli/angular",
             "segments/cli/argocd",
+            "segments/cli/aurelia",
             "segments/cli/bazel",
             "segments/cli/buf",
             "segments/cli/bun",
@@ -77,7 +82,9 @@ module.exports = {
             "segments/cli/pnpm",
             "segments/cli/quasar",
             "segments/cli/react",
+            "segments/cli/svelte",
             "segments/cli/talosctl",
+            "segments/cli/tauri",
             "segments/cli/terraform",
             "segments/cli/ui5tooling",
             "segments/cli/umbraco",
@@ -105,7 +112,7 @@ module.exports = {
         },
         {
           type: "category",
-          label: "💖 Health",
+          label: "🩺 Health",
           collapsed: true,
           items: [
             "segments/health/nightscout",
@@ -122,12 +129,15 @@ module.exports = {
             "segments/languages/dart",
             "segments/languages/dotnet",
             "segments/languages/elixir",
+            "segments/languages/fortran",
             "segments/languages/golang",
             "segments/languages/haskell",
             "segments/languages/java",
             "segments/languages/julia",
             "segments/languages/kotlin",
             "segments/languages/lua",
+            "segments/languages/mojo",
+            "segments/languages/nim",
             "segments/languages/node",
             "segments/languages/ocaml",
             "segments/languages/perl",
@@ -137,7 +147,9 @@ module.exports = {
             "segments/languages/ruby",
             "segments/languages/rust",
             "segments/languages/swift",
+            "segments/languages/v",
             "segments/languages/vala",
+            "segments/languages/zig",
           ]
         },
         {
@@ -152,7 +164,7 @@ module.exports = {
         },
         {
           type: "category",
-          label: "🧑‍💻 Source control",
+          label: "🗂️ Source control",
           collapsed: true,
           items: [
             "segments/scm/fossil",
@@ -203,7 +215,7 @@ module.exports = {
     },
     {
       type: "category",
-      label: "🙋🏾‍♀️ Contributing",
+      label: "🤝 Contributing",
       collapsed: true,
       items: [
         "contributing/started",
